@@ -12,6 +12,7 @@ from typing import IO, Any, List
 from apologies.demo import run_demo
 from apologies.game import MAX_PLAYERS, Game, GameMode
 from apologies.render import render_board
+from apologies.simulation import run_simulation
 from apologies.source import source
 
 # Constants used by the demo CLI
@@ -21,12 +22,17 @@ _DEMO_MODE_CHOICES = [GameMode.STANDARD.name, GameMode.ADULT.name]
 _DEMO_DEFAULT_SOURCE = "apologies.source.RandomInputSource"
 _DEMO_DEFAULT_DELAY_SEC = 1
 
+# Constants used by the simulation CLI
+_SIM_DEFAULT_ITERATIONS = 10
+_SIM_DEFAULT_OUT = "simulation.csv"
+
 
 def demo(argv: List[str], unused_stdout: IO[str], unused_stderr: IO[str]) -> None:
     """Run a game with simulated players, displaying output on the terminal."""
     parser = argparse.ArgumentParser(
         description="Run a game with simulated players, displaying output on the terminal.",
-        epilog="By default, the game runs in STANDARD mode with 4 players. A source is a class that chooses a player's move.",
+        epilog="By default, the game runs in %s mode with %d players. A source is a class that chooses a player's move."
+        % (_DEMO_DEFAULT_MODE, _DEMO_DEFAULT_PLAYERS),
     )
 
     parser.add_argument(
@@ -46,6 +52,38 @@ def demo(argv: List[str], unused_stdout: IO[str], unused_stderr: IO[str]) -> Non
     run_demo(players=args.players, mode=GameMode[args.mode], source=source(args.source), delay_sec=args.delay)
 
 
+def simulation(argv: List[str], unused_stdout: IO[str], unused_stderr: IO[str]) -> None:
+    """Run a simulation and display results."""
+    parser = argparse.ArgumentParser(
+        description="Run a simulation to see how well different character input sources behave.",
+        epilog="Every combination of game mode, number of players, and input source is tested, "
+        "using %d iterations by default.  A spreadsheet is generated containing statistics "
+        "on mean and median turns and duration to win, as well as number of wins for each "
+        "source." % _SIM_DEFAULT_ITERATIONS,
+    )
+
+    parser.add_argument("--iter", type=int, default=_SIM_DEFAULT_ITERATIONS, help="Number of iterations per scenario")
+
+    parser.add_argument("--out", type=str, default=_SIM_DEFAULT_OUT, help="Path to the output CSV file")
+
+    parser.add_argument(
+        "source", type=str, nargs="+", help="Fully-qualified name of the character sources to test",
+    )
+
+    args = parser.parse_args(args=argv[2:])
+
+    errors = []
+    if args.iter <= 0:
+        errors.append("simulation: error: there must be at least 1 iteration")
+
+    if errors:
+        parser.print_usage()
+        print("\n".join(errors))
+        sys.exit(1)
+
+    run_simulation(iterations=args.iter, output=args.out, sources=[source(s) for s in args.source])
+
+
 def render(unused_argv: List[str], stdout: IO[str], unused_stderr: IO[str]) -> None:
     """Render an empty board."""
     game = Game(4)
